.. _mission:

=======
Mission
=======

.. include:: _mission.rst

.. note::

  Our :ref:`roadmap` describes how we try to achieve our mission.


Motivation: Why we develop aeon
=================================

There are a number of reasons why we develop aeon, here are the most important ones:

* **Easier development of ML :term:`applications <application>`** with time series, by making the ecosystem more interoperable and usable as a whole, and by providing an easy-to-use and readable way of specifying and applying algorithms.
* **Easier ML algorithm development**, from research to implementation and testing.
* **Better ML algorithm research**, by facilitating reproducibility and fair evaluation and comparison of different algorithms.
* **Easier teaching and learning** for ML with time series.
* **Clearer time series methodology**, especially more consistent definitions, terminology and notation across learning tasks.
* **More collaboration and innovation**, by bringing together developers, practitioners and domain experts in a single project, by exploring a new community-driven model for the data science innovation cycle from methodology research to software development and deployment, and by offering alternative career paths for junior researchers and practitioners.
